@@ -38,7 +38,6 @@ pub trait SessionStateExt {
     /// State will be created with appropriate [SessionConfig] configured
     fn new_ballista_state(
         scheduler_url: String,
-        session_id: String,
     ) -> datafusion::error::Result<SessionState>;
     /// Upgrades [SessionState] for ballista usage
     ///
@@ -46,7 +45,6 @@ pub trait SessionStateExt {
     fn upgrade_for_ballista(
         self,
         scheduler_url: String,
-        session_id: String,
     ) -> datafusion::error::Result<SessionState>;
 }
 
@@ -57,6 +55,13 @@ pub trait SessionConfigExt {
     /// ballista configuration initialized
     fn new_with_ballista() -> SessionConfig;
 
+    /// update [SessionConfig] with Ballista specific settings
+    fn upgrade_for_ballista(self) -> SessionConfig;
+
+    /// return ballista specific configuration or
+    /// creates one if does not exist
+    fn ballista_config(&self) -> BallistaConfig;
+
     /// Overrides ballista's [LogicalExtensionCodec]
     fn with_ballista_logical_extension_codec(
         self,
@@ -131,7 +136,6 @@ pub trait SessionConfigHelperExt {
 impl SessionStateExt for SessionState {
     fn new_ballista_state(
         scheduler_url: String,
-        session_id: String,
     ) -> datafusion::error::Result<SessionState> {
         let session_config = SessionConfig::new_with_ballista();
         let planner = BallistaQueryPlanner::<LogicalPlanNode>::new(
@@ -145,7 +149,6 @@ impl SessionStateExt for SessionState {
             .with_config(session_config)
             .with_runtime_env(Arc::new(runtime_env))
             .with_query_planner(Arc::new(planner))
-            .with_session_id(session_id)
             .build();
 
         Ok(session_state)
@@ -154,35 +157,23 @@ impl SessionStateExt for SessionState {
     fn upgrade_for_ballista(
         self,
         scheduler_url: String,
-        session_id: String,
     ) -> datafusion::error::Result<SessionState> {
         let codec_logical = self.config().ballista_logical_extension_codec();
         let planner_override = self.config().ballista_query_planner();
 
-        let new_config = self
-            .config()
-            .options()
-            .extensions
-            .get::<BallistaConfig>()
-            .cloned()
-            .unwrap_or_else(BallistaConfig::default);
+        let session_config = self.config().clone().upgrade_for_ballista();
 
-        let session_config = self
-            .config()
-            .clone()
-            .with_option_extension(new_config.clone())
-            .ballista_restricted_configuration();
+        let ballista_config = session_config.ballista_config();
 
-        let builder = SessionStateBuilder::new_from_existing(self)
-            .with_config(session_config)
-            .with_session_id(session_id);
+        let builder =
+            SessionStateBuilder::new_from_existing(self).with_config(session_config);
 
         let builder = match planner_override {
             Some(planner) => builder.with_query_planner(planner),
             None => {
                 let planner = BallistaQueryPlanner::<LogicalPlanNode>::with_extension(
                     scheduler_url,
-                    new_config,
+                    ballista_config,
                     codec_logical,
                 );
                 builder.with_query_planner(Arc::new(planner))
@@ -201,6 +192,26 @@ impl SessionConfigExt for SessionConfig {
             .with_target_partitions(16)
             .ballista_restricted_configuration()
     }
+
+    fn upgrade_for_ballista(self) -> SessionConfig {
+        // if ballista config is not provided
+        // one is created and session state is updated
+        let ballista_config = self.ballista_config();
+
+        // session config has ballista config extension and
+        // default datafusion configuration is altered
+        // to fit ballista execution
+        self.with_option_extension(ballista_config)
+            .ballista_restricted_configuration()
+    }
+
+    fn ballista_config(&self) -> BallistaConfig {
+        self.options()
+            .extensions
+            .get::<BallistaConfig>()
+            .cloned()
+            .unwrap_or_else(BallistaConfig::default)
+    }
     fn with_ballista_logical_extension_codec(
         self,
         codec: Arc<dyn LogicalExtensionCodec>,
@@ -452,11 +463,8 @@ mod test {
     // Ballista disables round robin repatriations
     #[tokio::test]
     async fn should_disable_round_robin_repartition() {
-        let state = SessionState::new_ballista_state(
-            "scheduler_url".to_string(),
-            "session_id".to_string(),
-        )
-        .unwrap();
+        let state =
+            SessionState::new_ballista_state("scheduler_url".to_string()).unwrap();
 
         assert!(!state.config().round_robin_repartition());
 
@@ -464,7 +472,7 @@ mod test {
 
         assert!(state.config().round_robin_repartition());
         let state = state
-            .upgrade_for_ballista("scheduler_url".to_string(), "session_id".to_string())
+            .upgrade_for_ballista("scheduler_url".to_string())
             .unwrap();
 
         assert!(!state.config().round_robin_repartition());
