@@ -28,8 +28,6 @@ pub mod scheduler_server;
 pub mod standalone;
 pub mod state;
 
-#[cfg(feature = "flight-sql")]
-pub mod flight_sql;
 #[cfg(test)]
 pub mod test_utils;
 
