@@ -23,13 +23,12 @@ use ballista_core::serde::protobuf::scheduler_grpc_server::SchedulerGrpc;
 use ballista_core::serde::protobuf::{
     execute_query_failure_result, execute_query_result, AvailableTaskSlots,
     CancelJobParams, CancelJobResult, CleanJobDataParams, CleanJobDataResult,
-    CreateSessionParams, CreateSessionResult, ExecuteQueryFailureResult,
+    CreateUpdateSessionParams, CreateUpdateSessionResult, ExecuteQueryFailureResult,
     ExecuteQueryParams, ExecuteQueryResult, ExecuteQuerySuccessResult, ExecutorHeartbeat,
     ExecutorStoppedParams, ExecutorStoppedResult, GetJobStatusParams, GetJobStatusResult,
     HeartBeatParams, HeartBeatResult, PollWorkParams, PollWorkResult,
     RegisterExecutorParams, RegisterExecutorResult, RemoveSessionParams,
-    RemoveSessionResult, UpdateSessionParams, UpdateSessionResult,
-    UpdateTaskStatusParams, UpdateTaskStatusResult,
+    RemoveSessionResult, UpdateTaskStatusParams, UpdateTaskStatusResult,
 };
 use ballista_core::serde::scheduler::ExecutorMetadata;
 use datafusion_proto::logical_plan::AsLogicalPlan;
@@ -189,7 +188,7 @@ impl<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan> SchedulerGrpc
             status,
             metadata,
         } = request.into_inner();
-        debug!("Received heart beat request for {:?}", executor_id);
+        trace!("Received heart beat request for {:?}", executor_id);
 
         // If not registered, do registration first before saving heart beat
         if let Err(e) = self
@@ -272,51 +271,27 @@ impl<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan> SchedulerGrpc
         Ok(Response::new(UpdateTaskStatusResult { success: true }))
     }
 
-    async fn create_session(
+    async fn create_update_session(
         &self,
-        request: Request<CreateSessionParams>,
-    ) -> Result<Response<CreateSessionResult>, Status> {
+        request: Request<CreateUpdateSessionParams>,
+    ) -> Result<Response<CreateUpdateSessionResult>, Status> {
         let session_params = request.into_inner();
 
         let session_config = self.state.session_manager.produce_config();
         let session_config =
             session_config.update_from_key_value_pair(&session_params.settings);
 
-        let ctx = self
+        let _ = self
             .state
             .session_manager
-            .create_session(&session_config)
-            .await
-            .map_err(|e| {
-                Status::internal(format!("Failed to create SessionContext: {e:?}"))
-            })?;
+            .create_or_update_session(&session_params.session_id, &session_config)
+            .await;
 
-        Ok(Response::new(CreateSessionResult {
-            session_id: ctx.session_id(),
+        Ok(Response::new(CreateUpdateSessionResult {
+            session_id: session_params.session_id,
         }))
     }
 
-    async fn update_session(
-        &self,
-        request: Request<UpdateSessionParams>,
-    ) -> Result<Response<UpdateSessionResult>, Status> {
-        let session_params = request.into_inner();
-
-        let session_config = self.state.session_manager.produce_config();
-        let session_config =
-            session_config.update_from_key_value_pair(&session_params.settings);
-
-        self.state
-            .session_manager
-            .update_session(&session_params.session_id, &session_config)
-            .await
-            .map_err(|e| {
-                Status::internal(format!("Failed to create SessionContext: {e:?}"))
-            })?;
-
-        Ok(Response::new(UpdateSessionResult { success: true }))
-    }
-
     async fn remove_session(
         &self,
         request: Request<RemoveSessionParams>,
@@ -344,6 +319,7 @@ impl<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan> SchedulerGrpc
         if let ExecuteQueryParams {
             query: Some(query),
             session_id,
+            operation_id,
             settings,
         } = query_params
         {
@@ -353,58 +329,26 @@ impl<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan> SchedulerGrpc
                 .and_then(|s| s.value.clone())
                 .unwrap_or_default();
 
-            let (session_id, session_ctx) = match session_id {
-                Some(session_id) => {
-                    match self.state.session_manager.get_session(&session_id).await {
-                        Ok(ctx) => {
-                            // Update [SessionConfig] using received properties
+            let job_id = self.state.task_manager.generate_job_id();
 
-                            // TODO MM can we do something better here?
-                            // move this to update session and use .update_session(&session_params.session_id, &session_config)
-                            // instead of get_session.
-                            //
-                            // also we should consider sending properties if/when changed rather than
-                            // all properties every time
+            info!("execution query - session_id: {}, operation_id: {}, job_name: {}, job_id: {}", session_id, operation_id, job_name, job_id);
 
-                            let state = ctx.state_ref();
-                            let mut state = state.write();
-                            let config = state.config_mut();
-                            config.update_from_key_value_pair_mut(&settings);
+            let (session_id, session_ctx) = {
+                let session_config = self.state.session_manager.produce_config();
+                let session_config = session_config.update_from_key_value_pair(&settings);
 
-                            (session_id, ctx)
-                        }
-                        Err(e) => {
-                            let msg = format!("Failed to load SessionContext for session ID {session_id}: {e}");
-                            error!("{}", msg);
-                            return Ok(Response::new(ExecuteQueryResult {
-                                result: Some(execute_query_result::Result::Failure(
-                                    ExecuteQueryFailureResult {
-                                        failure: Some(execute_query_failure_result::Failure::SessionNotFound(msg)),
-                                    },
-                                )),
-                            }));
-                        }
-                    }
-                }
-                _ => {
-                    // Create default config
-                    let session_config = self.state.session_manager.produce_config();
-                    let session_config =
-                        session_config.update_from_key_value_pair(&settings);
+                let ctx = self
+                    .state
+                    .session_manager
+                    .create_or_update_session(&session_id, &session_config)
+                    .await
+                    .map_err(|e| {
+                        Status::internal(format!(
+                            "Failed to create SessionContext: {e:?}"
+                        ))
+                    })?;
 
-                    let ctx = self
-                        .state
-                        .session_manager
-                        .create_session(&session_config)
-                        .await
-                        .map_err(|e| {
-                            Status::internal(format!(
-                                "Failed to create SessionContext: {e:?}"
-                            ))
-                        })?;
-
-                    (ctx.session_id(), ctx)
-                }
+                (session_id, ctx)
             };
 
             let plan = match query {
@@ -421,6 +365,7 @@ impl<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan> SchedulerGrpc
                                 format!("Could not parse logical plan protobuf: {e}");
                             error!("{}", msg);
                             return Ok(Response::new(ExecuteQueryResult {
+                                operation_id,
                                 result: Some(execute_query_result::Result::Failure(
                                     ExecuteQueryFailureResult {
                                         failure: Some(execute_query_failure_result::Failure::PlanParsingFailure(msg)),
@@ -441,6 +386,7 @@ impl<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan> SchedulerGrpc
                             let msg = format!("Error parsing SQL: {e}");
                             error!("{}", msg);
                             return Ok(Response::new(ExecuteQueryResult {
+                                operation_id,
                                 result: Some(execute_query_result::Result::Failure(
                                     ExecuteQueryFailureResult {
                                         failure: Some(execute_query_failure_result::Failure::PlanParsingFailure(msg)),
@@ -457,20 +403,20 @@ impl<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan> SchedulerGrpc
                 plan.display_indent()
             );
 
-            let job_id = self.state.task_manager.generate_job_id();
-
             log::trace!("setting job name: {}", job_name);
-            self.submit_job(&job_id, &job_name, session_ctx, &plan)
+            let job_id = self
+                .submit_job(&job_name, session_ctx, &plan)
                 .await
                 .map_err(|e| {
                     let msg =
-                        format!("Failed to send JobQueued event for {job_id}: {e:?}");
+                        format!("Failed to send JobQueued event for {job_name}: {e:?}");
                     error!("{}", msg);
 
                     Status::internal(msg)
                 })?;
 
             Ok(Response::new(ExecuteQueryResult {
+                operation_id,
                 result: Some(execute_query_result::Result::Success(
                     ExecuteQuerySuccessResult { job_id, session_id },
                 )),
@@ -534,20 +480,12 @@ impl<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan> SchedulerGrpc
         let job_id = request.into_inner().job_id;
         info!("Received cancellation request for job {}", job_id);
 
-        self.query_stage_event_loop
-            .get_sender()
-            .map_err(|e| {
-                let msg = format!("Get query stage event loop error due to {e:?}");
-                error!("{}", msg);
-                Status::internal(msg)
-            })?
-            .post_event(QueryStageSchedulerEvent::JobCancel(job_id))
-            .await
-            .map_err(|e| {
-                let msg = format!("Post to query stage event loop error due to {e:?}");
-                error!("{}", msg);
-                Status::internal(msg)
-            })?;
+        self.cancel_job(job_id).await.map_err(|e| {
+            let msg = format!("Post to query stage event loop error due to {e:?}");
+            error!("{}", msg);
+            Status::internal(msg)
+        })?;
+
         Ok(Response::new(CancelJobResult { cancelled: true }))
     }
 
