@@ -476,29 +476,22 @@ impl SchedulerTest {
         self.scheduler
             .state
             .session_manager
-            .create_session(&self.session_config)
+            .create_or_update_session("session_id", &self.session_config)
             .await
     }
 
-    pub async fn submit(
-        &mut self,
-        job_id: &str,
-        job_name: &str,
-        plan: &LogicalPlan,
-    ) -> Result<()> {
+    pub async fn submit(&mut self, job_name: &str, plan: &LogicalPlan) -> Result<String> {
         println!("{:?}", self.session_config);
         let ctx = self
             .scheduler
             .state
             .session_manager
-            .create_session(&self.session_config)
+            .create_or_update_session("session_id", &self.session_config)
             .await?;
 
-        self.scheduler
-            .submit_job(job_id, job_name, ctx, plan)
-            .await?;
+        let job_id = self.scheduler.submit_job(job_name, ctx, plan).await?;
 
-        Ok(())
+        Ok(job_id)
     }
 
     pub async fn post_scheduler_event(
@@ -606,22 +599,20 @@ impl SchedulerTest {
         final_status
     }
 
+    /// Returns job status and job_id
     pub async fn run(
         &mut self,
-        job_id: &str,
         job_name: &str,
         plan: &LogicalPlan,
-    ) -> Result<JobStatus> {
+    ) -> Result<(JobStatus, String)> {
         let ctx = self
             .scheduler
             .state
             .session_manager
-            .create_session(&self.session_config)
+            .create_or_update_session("session_id", &self.session_config)
             .await?;
 
-        self.scheduler
-            .submit_job(job_id, job_name, ctx, plan)
-            .await?;
+        let job_id = self.scheduler.submit_job(job_name, ctx, plan).await?;
 
         let mut receiver = self.status_receiver.take().unwrap();
 
@@ -640,7 +631,7 @@ impl SchedulerTest {
                 .scheduler
                 .state
                 .task_manager
-                .get_job_status(job_id)
+                .get_job_status(&job_id)
                 .await?;
 
             if let Some(JobStatus {
@@ -659,7 +650,7 @@ impl SchedulerTest {
             tokio::time::sleep(Duration::from_millis(100)).await
         };
 
-        final_status
+        final_status.map(|s| (s, job_id))
     }
 }
 
@@ -746,7 +737,7 @@ pub fn assert_submitted_event(job_id: &str, collector: &TestMetricsCollector) {
         .iter()
         .any(|ev| matches!(ev, MetricEvent::Submitted(_, _, _)));
 
-    assert!(found, "{}", "Expected submitted event for job {job_id}");
+    assert!(found, "Expected submitted event for job {job_id}");
 }
 
 pub fn assert_no_submitted_event(job_id: &str, collector: &TestMetricsCollector) {
@@ -755,7 +746,7 @@ pub fn assert_no_submitted_event(job_id: &str, collector: &TestMetricsCollector)
         .iter()
         .any(|ev| matches!(ev, MetricEvent::Submitted(_, _, _)));
 
-    assert!(!found, "{}", "Expected no submitted event for job {job_id}");
+    assert!(!found, "Expected no submitted event for job {job_id}");
 }
 
 pub fn assert_completed_event(job_id: &str, collector: &TestMetricsCollector) {
@@ -782,7 +773,7 @@ pub fn assert_failed_event(job_id: &str, collector: &TestMetricsCollector) {
         .iter()
         .any(|ev| matches!(ev, MetricEvent::Failed(_, _, _)));
 
-    assert!(found, "{}", "Expected failed event for job {job_id}");
+    assert!(found, "Expected failed event for job {job_id}");
 }
 
 pub fn revive_graph_and_complete_next_stage(graph: &mut ExecutionGraph) -> Result<usize> {
